# pyNIBS
Preprocessing, postprocessing, and analyses routines for non-invasive brain stimulation experiments.


## Install
Via pip:

``` bash
pip install pynibs
```

Or clone repo and install via `setup.py`:

``` bash
git clone https://gitlab.gwdg.de/tms-localization/pynibs
cd pynibs
python setup.py develop
```

## Bugs
Yes. Drop us a line if you find any or feel free to file a PR.